==> risk-center-api-0.5.7-20190814.033503-8-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskMaterialSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * 广告素材所属行业标记表
 */
@ApiModel
public class RiskMaterialSignDto implements Serializable {

    private static final long serialVersionUID = 1L;
    @ApiModelProperty("id")
    private Long id;

    @ApiModelProperty("竞品id")
    private Long competeId;

    @ApiModelProperty("竞品巡查日志id")
    private Long competeLogId;

    @ApiModelProperty("行业id")
    private Long industryId;

    @ApiModelProperty("广告素材序号")
    private Integer materialNum;

    @ApiModelProperty("修改者")
    private String editor;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("修改时间")
    private Date gmtModified;

    @ApiModelProperty("关键词类型0:行业；1:资源")
    private Integer wordType;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCompeteId() {
        return competeId;
    }

    public void setCompeteId(Long competeId) {
        this.competeId = competeId;
    }

    public Long getCompeteLogId() {
        return competeLogId;
    }

    public void setCompeteLogId(Long competeLogId) {
        this.competeLogId = competeLogId;
    }

    public Long getIndustryId() {
        return industryId;
    }

    public void setIndustryId(Long industryId) {
        this.industryId = industryId;
    }

    public Integer getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(Integer materialNum) {
        this.materialNum = materialNum;
    }

    public String getEditor() {
        return editor;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getWordType() {
        return wordType;
    }

    public void setWordType(Integer wordType) {
        this.wordType = wordType;
    }
}

==> risk-center-api-0.5.7-20190815.020821-20-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskMaterialSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * 广告素材所属行业标记表
 */
@ApiModel
public class RiskMaterialSignDto implements Serializable {

    private static final long serialVersionUID = 1L;
    @ApiModelProperty("id")
    private Long id;

    @ApiModelProperty("竞品id")
    private Long competeId;

    @ApiModelProperty("竞品巡查日志id")
    private Long competeLogId;

    @ApiModelProperty("行业id")
    private Long industryId;

    @ApiModelProperty("广告素材序号")
    private Integer materialNum;

    @ApiModelProperty("修改者")
    private String editor;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("修改时间")
    private Date gmtModified;

    @ApiModelProperty("关键词类型0:行业；1:资源")
    private Integer wordType;

    @ApiModelProperty("是否同步标签：true 是;false 否")
    private Boolean isSync;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCompeteId() {
        return competeId;
    }

    public void setCompeteId(Long competeId) {
        this.competeId = competeId;
    }

    public Long getCompeteLogId() {
        return competeLogId;
    }

    public void setCompeteLogId(Long competeLogId) {
        this.competeLogId = competeLogId;
    }

    public Long getIndustryId() {
        return industryId;
    }

    public void setIndustryId(Long industryId) {
        this.industryId = industryId;
    }

    public Integer getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(Integer materialNum) {
        this.materialNum = materialNum;
    }

    public String getEditor() {
        return editor;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getWordType() {
        return wordType;
    }

    public void setWordType(Integer wordType) {
        this.wordType = wordType;
    }

    public Boolean getSync() {
        return isSync;
    }

    public void setSync(Boolean sync) {
        isSync = sync;
    }
}
